@@ -44,7 +44,7 @@ def ReadAccSensor():
     coords=[0, 0, 0]
     if(data.DeviceIsN900==True):
         for i in range(data.Sample_smoothing):
-            f = open("/sys/class/i2c-adapter/i2c-3/3-001d/coord", 'r' )
+            f = open(data.Acceleration_Sensor, 'r' )
             coords_tmp = [int(w) for w in f.readline().split()]
             f.close()
             coords[0]=coords[0] + coords_tmp[0] #X
